@@ -49,6 +49,11 @@ BEGIN{
 END{
 }
 
+use File::Temp qw(tempfile);
+use File::Spec;
+use Util::Properties;
+
+
 my $isCGI;
 use CGI qw(:standard);
 if($isCGI){
@@ -99,6 +104,11 @@ if($query->param('doc')){
   exit(0);
 }
 
+if ($query->param('action') eq 'upload'){
+  uploadManager();
+  exit(0);
+}
+
 unless($query->param('inputfile')){
   my %cookies=$query->cookie('cgiConvertSpectra.pl');
   my $inputformat=$cookies{inputformat};
@@ -518,6 +528,7 @@ sub findCmdPrefix{
   return undef;
 }
 
+
 __DATA__
 <html>
   <head>
